@@ -18,7 +18,7 @@ build_time_vars = {'ABIFLAGS': '',
  'BLDSHARED': '/usr/bin/ccache gcc '
               '-I/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
               '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib '
-              '-pthread -shared '
+              '-shared '
               '-L/home/buildslave/build/workdir/UnpackedTarball/libffi/aarch64-unknown-linux-gnu/.libs '
               '-L/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
               '-L/home/buildslave/build/workdir/LinkTarget/StaticLibrary '
@@ -30,9 +30,10 @@ build_time_vars = {'ABIFLAGS': '',
  'BYTESTR_DEPS': '\\',
  'CC': '/usr/bin/ccache gcc '
        '-I/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
-       '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib -pthread',
+       '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wsign-compare -DNDEBUG -g  -O3 -Wall',
+ 'CFLAGS': '-Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -g  -O3 '
+           '-Wall',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -51,14 +52,15 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIGURE_LDFLAGS_NOLTO': '',
  'CONFIG_ARGS': "'--build=aarch64-unknown-linux-gnu' "
-                "'--host=aarch64-unknown-linux-gnu' '--prefix=/python-inst' "
-                "'--with-system-expat' '--enable-shared' "
+                "'--host=aarch64-unknown-linux-gnu' '--with-valgrind' "
+                "'--prefix=/python-inst' '--with-system-expat' "
+                "'--enable-shared' "
                 "'--with-openssl=/home/buildslave/build/workdir/UnpackedTarball/openssl' "
                 "'PKG_CONFIG_LIBDIR=/home/buildslave/build/workdir/UnpackedTarball/libffi/aarch64-unknown-linux-gnu' "
                 "'CC=/usr/bin/ccache gcc "
                 '-I/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
                 "-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib' "
-                "'CFLAGS=   ' "
+                "'CFLAGS=       ' "
                 "'LDFLAGS=-L/home/buildslave/build/workdir/UnpackedTarball/libffi/aarch64-unknown-linux-gnu/.libs "
                 '-L/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
                 '-L/home/buildslave/build/workdir/LinkTarget/StaticLibrary '
@@ -80,7 +82,7 @@ build_time_vars = {'ABIFLAGS': '',
                             '--title "CPython 3.11 LCOV report [commit $(shell '
                             ')]"',
  'CPPFLAGS': '-I. -I./Include',
- 'CXX': '/usr/bin/ccache g++  -pthread',
+ 'CXX': '/usr/bin/ccache g++',
  'DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
                    '-DHAVE_UINT128_T=1',
  'DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
@@ -168,7 +170,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_CLOCK_GETTIME': 1,
  'HAVE_CLOCK_NANOSLEEP': 1,
  'HAVE_CLOCK_SETTIME': 1,
- 'HAVE_CLOSE_RANGE': 0,
+ 'HAVE_CLOSE_RANGE': 1,
  'HAVE_COMPUTED_GOTOS': 1,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
@@ -347,7 +349,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LINUX_AUXVEC_H': 1,
  'HAVE_LINUX_CAN_BCM_H': 1,
  'HAVE_LINUX_CAN_H': 1,
- 'HAVE_LINUX_CAN_J1939_H': 0,
+ 'HAVE_LINUX_CAN_J1939_H': 1,
  'HAVE_LINUX_CAN_RAW_FD_FRAMES': 1,
  'HAVE_LINUX_CAN_RAW_H': 1,
  'HAVE_LINUX_CAN_RAW_JOIN_FILTERS': 1,
@@ -449,7 +451,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SCHED_SETAFFINITY': 1,
  'HAVE_SCHED_SETPARAM': 1,
  'HAVE_SCHED_SETSCHEDULER': 1,
- 'HAVE_SEM_CLOCKWAIT': 0,
+ 'HAVE_SEM_CLOCKWAIT': 1,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 1,
@@ -629,7 +631,7 @@ build_time_vars = {'ABIFLAGS': '',
  'INSTSONAME': 'libpython3.11.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': '/usr/bin/ccache g++  -pthread -shared',
+ 'LDCXXSHARED': '/usr/bin/ccache g++ -shared',
  'LDFLAGS': '-L/home/buildslave/build/workdir/UnpackedTarball/libffi/aarch64-unknown-linux-gnu/.libs '
             '-L/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
             '-L/home/buildslave/build/workdir/LinkTarget/StaticLibrary '
@@ -640,7 +642,7 @@ build_time_vars = {'ABIFLAGS': '',
  'LDSHARED': '/usr/bin/ccache gcc '
              '-I/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
              '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib '
-             '-pthread -shared '
+             '-shared '
              '-L/home/buildslave/build/workdir/UnpackedTarball/libffi/aarch64-unknown-linux-gnu/.libs '
              '-L/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
              '-L/home/buildslave/build/workdir/LinkTarget/StaticLibrary '
@@ -650,8 +652,9 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDEST': '/python-inst/lib/python3.11',
  'LIBDIR': '/python-inst/lib',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-Wsign-compare -DNDEBUG -g  -O3 -Wall -std=c11 -Wextra '
-                    '-Wno-unused-parameter -Wno-missing-field-initializers '
+ 'LIBEXPAT_CFLAGS': '-Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
+                    '-g  -O3 -Wall -std=c11 -Wextra -Wno-unused-parameter '
+                    '-Wno-missing-field-initializers '
                     '-Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                     '-fPIC -fPIC',
@@ -661,7 +664,8 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
-                    '-DHAVE_UINT128_T=1 -Wsign-compare -DNDEBUG -g  -O3 -Wall '
+                    '-DHAVE_UINT128_T=1 -Wsign-compare '
+                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -g  -O3 -Wall '
                     '-std=c11 -Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers '
                     '-Werror=implicit-function-declaration '
@@ -678,12 +682,11 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBRARY_DEPS': 'libpython3.11.a libpython3.11.so libpython3.so',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
- 'LIBS': '-lpthread -ldl  -lutil',
+ 'LIBS': '-ldl',
  'LIBSUBDIRS': 'asyncio \\',
  'LINKCC': '/usr/bin/ccache gcc '
            '-I/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
-           '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib '
-           '-pthread',
+           '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
  'LINK_PYTHON_DEPS': 'libpython3.11.a libpython3.11.so libpython3.so',
  'LINK_PYTHON_OBJS': '-L. -lpython3.11',
@@ -700,8 +703,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': '/usr/bin/ccache gcc '
            '-I/home/buildslave/build/workdir/UnpackedTarball/bzip2 '
-           '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib '
-           '-pthread',
+           '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
@@ -853,7 +855,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__OPERATOR_LDFLAGS': '',
  'MODULE__PICKLE_STATE': 'yes',
  'MODULE__POSIXSHMEM_CFLAGS': '-I./Modules/_multiprocessing',
- 'MODULE__POSIXSHMEM_LDFLAGS': '-lrt',
+ 'MODULE__POSIXSHMEM_LDFLAGS': '',
  'MODULE__POSIXSHMEM_STATE': 'yes',
  'MODULE__POSIXSUBPROCESS_STATE': 'yes',
  'MODULE__QUEUE_STATE': 'yes',
@@ -920,7 +922,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_LDFLAGS': '-L/home/buildslave/build/workdir/UnpackedTarball/openssl/lib',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPENSSL_RPATH': '',
- 'OPT': '-DNDEBUG -g  -O3 -Wall',
+ 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -g  -O3 -Wall',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -956,20 +958,23 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -DNDEBUG -g  -O3 -Wall -std=c11 '
-                             '-Wextra -Wno-unused-parameter '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1 '
+                             '-DNDEBUG -g  -O3 -Wall -std=c11 -Wextra '
+                             '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
                              '-I./Include -fPIC -DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wsign-compare -DNDEBUG -g  -O3 -Wall',
+ 'PY_CFLAGS': '-Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -g  -O3 '
+              '-Wall',
  'PY_CFLAGS_NODIST': '-std=c11 -Wextra -Wno-unused-parameter '
                      '-Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wsign-compare -DNDEBUG -g  -O3 -Wall -std=c11 -Wextra '
-                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+ 'PY_CORE_CFLAGS': '-Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
+                   '-g  -O3 -Wall -std=c11 -Wextra -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-L/home/buildslave/build/workdir/UnpackedTarball/libffi/aarch64-unknown-linux-gnu/.libs '
@@ -992,9 +997,9 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SQLITE_HAVE_SERIALIZE': 0,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wsign-compare -DNDEBUG -g  -O3 -Wall -std=c11 '
-                        '-Wextra -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers '
+ 'PY_STDMODULE_CFLAGS': '-Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1 '
+                        '-DNDEBUG -g  -O3 -Wall -std=c11 -Wextra '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include -fPIC',
@@ -1013,7 +1018,7 @@ build_time_vars = {'ABIFLAGS': '',
  'SCRIPTDIR': '/python-inst/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
- 'SHLIBS': '-lpthread -ldl  -lutil',
+ 'SHLIBS': '-ldl',
  'SHLIB_SUFFIX': '.so',
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
@@ -1084,7 +1089,7 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_LIBINTL': 0,
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
- 'WITH_VALGRIND': 0,
+ 'WITH_VALGRIND': 1,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
  'abs_builddir': '/home/buildslave/build/workdir/UnpackedTarball/python3',
